@@ -12,6 +12,7 @@ server_fct <- function(input, output, session){
   lat <- NULL
   lon <- NULL
   aims_example <- NULL
+  genotype <- NULL
   ## build fixes : end ##
   if(!exists("db_list")) db_list <- get("db_list", envir = -2)
   if(!exists("reporting_panel")) reporting_panel <- get("reporting_panel", envir = -2)
@@ -24,18 +25,43 @@ server_fct <- function(input, output, session){
   ## USER INTERFACE
   output$analysis <- renderUI({
     res <- result()
+    prof <- Profile()
+    dat <- Dataset()
     if(is.null(res)){
-      fluidPage(
-        h3("Upload valid AIMs profile"),
-        HTML("<p>Upload valid file first: It must contain a column named <tt>Target.ID</tt> 
-           containing marker (locus) names, and <tt>Genotype</tt> with the genotypes as e.g. 
-           <tt>AA</tt> or <tt>AC</tt></p>"),
-        HTML("You can download a sample file showing the necessary columns and data structure here:"),
-        downloadLink("download_sample", "Download")
-      )
+      if(is.null(dat) || nrow(dat) == 0){
+        fluidPage(
+          h3("Upload valid AIMs profile"),
+          HTML("<p>Upload valid file: It must contain a column  
+             containing marker (locus) names, and a column with the genotypes as e.g. 
+             <tt>AA</tt> or <tt>AC</tt></p>"),
+          HTML("You can download a sample file showing the necessary columns and data structure here:"),
+          downloadLink("download_sample", "Download")
+        )
+      }
+      else{
+        ## Make column suggestions
+        guess_locus_text <- and_text(pre = "<p>Suggestions for <b>locus column</b>: ", x = columns$locus_guess, post = "</p>")
+        guess_genotype_text <- and_text(pre = "<p>Suggestions for <b>genotype column</b>: ", x = columns$genotype_guess, post = "</p>")
+        #
+        fluidPage(
+          fluidRow(h3("Uploaded file")),
+          fluidRow(
+            HTML("<p>The first few rows of the uploaded file are shown below</p>"),
+            HTML(guess_locus_text),
+            HTML(guess_genotype_text)
+          ),
+          fluidRow(
+            renderDT({
+              datatable(dat, options(dom = "t"))
+            })
+          )
+        )
+      }
     }
     else{
       fluidPage(
+        tags$head(tags$style(paste0(".modal-lg{ width: ", 2*session$clientData$output_barplot_width,"px}"))),
+        ## tags$style(HTML('table.dataTable tr.selected td, table.dataTable td.selected {background-color: none !important; font-weight: bold;}')),
         fluidRow(HTML(paste0("<p><b>Analysis of file:</b> ",input$profile_file$name,":")),
                  actionLink("show_profile", label = "Show profile"),
                  icon("new-window", lib = "glyphicon"),
@@ -47,9 +73,12 @@ server_fct <- function(input, output, session){
           column(width = 6, uiOutput("map_panel") )
         ),
         fluidRow(tags$h2("Tables")),
-        fluidRow(div(style = "opacity = 0.5;", DTOutput("result_table"))),
+        fluidRow(DTOutput("result_table")),
         fluidRow(tags$h2("Likelihood ratios")),
-        fluidRow(DTOutput("lr_list"))
+        fluidRow(
+          column(width = 6, DTOutput("lr_list")),
+          column(width = 6, uiOutput("LRplot_panel") )
+        )
       )
     }
   })
@@ -72,15 +101,43 @@ server_fct <- function(input, output, session){
   observeEvent(input$show_profile, {
     A1 <- NULL
     A2 <- NULL
+    profile <- Profile() %>% 
+      profile_AA_x0(df = db$db, select = c("locus", "A1", "A2"), keep_dropped = TRUE)
+    profile_drop <- profile$profile_drop %>% 
+      mutate(genotype = paste0(A1, A2)) %>% select(locus, genotype)
+    profile_x0 <- profile$profile_x0 %>% 
+      mutate(genotype = paste0(A1, A2)) %>% select(locus, genotype)
     showModal(modalDialog(
       title = paste("Uploaded profile:",input$profile_file$name),
-      renderDT(Profile() %>% mutate(genotype = paste0(A1, A2)) %>% 
-                 select_("locus", "genotype") %>% 
+      size = "m",
+      h3("Analysed loci"),
+      helpText("The loci below has been included in the analysis."),
+      renderDT(profile_x0 %>% 
                DT::datatable(rownames=FALSE, filter = "bottom", selection = 'none',
-               extensions = 'Buttons', options = list(
-                 dom = 'Blfrtip',
-                 buttons = c('copy', 'csv', 'excel', 'pdf', 'print')
-               ))),
+                             extensions = 'Buttons', 
+                             options = list(
+                               dom = 'Blfrtip',
+                               buttons = c('copy', 'csv', 'excel', 'pdf', 'print'),
+                               lengthMenu = list(c(10, 25, 50, 100, -1),
+                                                 c("10", "25", "50", "100", "All"))
+                               )
+                             )
+               ),
+      h3("Dropped loci"),
+      helpText(paste0("The loci below has been excluded from the analysis.\n
+               Either because of state 'NN', locus not in '",input$snp_set,"' 
+                      or other typing error (e.g. different reference allele).")),
+      renderDT(profile_drop %>% 
+                 DT::datatable(rownames=FALSE, filter = "bottom", selection = 'none',
+                               extensions = 'Buttons', 
+                               options = list(
+                                 dom = 'Blfrtip',
+                                 buttons = c('copy', 'csv', 'excel', 'pdf', 'print'),
+                                 lengthMenu = list(c(10, 25, 50, 100, -1),
+                                                   c("10", "25", "50", "100", "All"))
+                               )
+                 )
+      ),
       footer = modalButton("Close"),
       easyClose = TRUE
       ))
@@ -102,6 +159,21 @@ server_fct <- function(input, output, session){
   bar_ranges <- reactiveValues(x = NULL, y = NULL)
   map_ranges <- reactiveValues(x = NULL, y = NULL)
   LR_lists <- reactiveValues(pop = NULL, meta = NULL)
+  columns <- reactiveValues(locus = "Target.ID", locus_guess = NULL,
+                            genotype = "Genotype", genotype_guess = NULL)
+  
+  output$column_panel <- renderUI({
+    sel_locus <- input$col_locus
+    sel_genotype <- input$col_genotype
+    opt_locus <- columns$locus
+    opt_genotype <- columns$genotype
+    ## if(!is.null(sel_locus)) opt_genotype <- opt_genotype[!grepl(sel_locus, opt_genotype)]
+    verticalLayout(
+      selectInput(inputId = "col_locus", label = "Locus column:", choices = opt_locus, multiple = FALSE, selected = sel_locus),
+      selectInput(inputId = "col_genotype", label = "Genotype column:", choices = opt_genotype, multiple = FALSE, selected = sel_genotype)
+    )
+  })
+  
   
   observe({
     db$db <- db_list[[ifelse(is.null(input$snp_set), 1, input$snp_set)]]
@@ -123,33 +195,56 @@ server_fct <- function(input, output, session){
       return(tibble())
     }
     ## data <- read.csv(input$profile_file$datapath, header = TRUE, stringsAsFactors = FALSE) %>% as_tibble()
-    data <- rio::import(input$profile_file$datapath) %>% as_tibble()
-    if(!all(c("Target.ID", "Genotype") %in% names(data))) return(tibble())
-    ## Arguments specific for RGA files
-    data %>% select(locus = Target.ID, Genotype) %>% 
-      extract(col = Genotype, into = c("A1","A2"), regex = "(.{1})(.{1})", remove = TRUE) %>% 
-      arrange(locus)
+    # browser()
+    ext <- rio::get_ext(input$profile_file$datapath)
+    if(grepl("xls", ext)) data <- rio::import(input$profile_file$datapath) %>% as_tibble()
+    else data <- rio::import(input$profile_file$datapath, header = TRUE) %>% as_tibble()
+    ## data %>% head() %>% print()
+    ## Remove NA columns
+    data <- data %>% select(which(map_lgl(.x = ., .f = ~ !all(is.na(.x)))))
+    ndata <- names(data)
+    ## Update columns:
+    columns$locus <- ndata
+    columns$genotype <- ndata
+    ## 
+    columns$locus_guess <- nullset(ndata, map_lgl(data, function(x) all(grepl(pattern = "^rs.*", x))))
+    columns$genotype_guess <- nullset(ndata, map_lgl(data, function(x) all(nchar(x)<=2) & all(unlist(strsplit(paste(x),"")) %in% c("A", "C", "G", "T", "N", "-"))))
+    ##
+    updateSelectInput(session, inputId = "col_locus", selected = columns$locus_guess[1])
+    updateSelectInput(session, inputId = "col_genotype", selected = columns$genotype_guess[1])
+    ## return read data
+    data
   })
   
   Profile <- reactive({
     profile <- Dataset()
-    if(is.null(profile)) return(NULL) ## No profile
-    if(!is.null(input$profile_file) & nrow(profile)==0){
-      showModal(
-        modalDialog(title = "Error in reading file",
-                    fluidPage(
-                      helpText("File not correct format"),
-                      helpText("See the example file for correct columns")
-                      )
-        ))
-      shinyjs::reset("profile_file")
-      return(NULL) ## No profile
+    if(is.null(profile) | nrow(profile) == 0) return(NULL) ## No profile
+    ##
+    nprofile <- names(profile)
+    col_return <- FALSE
+    if(!(input$col_locus %in% nprofile)){ 
+      updateSelectInput(session, inputId = "col_locus", selected = NULL) 
+      col_return <- TRUE
+      }
+    if(!(input$col_genotype %in% nprofile)){ 
+      updateSelectInput(session, inputId = "col_genotype", selected = NULL) 
+      col_return <- TRUE
     }
-    if(nrow(profile)==0) return(NULL) ## No profile
-    updateSelectizeInput(session, "lr_meta", selected = NULL)
-    updateSelectizeInput(session, "lr_pop", selected = NULL)
-    ## shinyjs::reset("lr_meta")
-    ## shinyjs::reset("lr_pop")
+    if(col_return) return(NULL)
+    ##
+    if(input$col_locus == input$col_genotype) return(NULL)
+    profile <- profile %>% 
+      select_(locus = paste0("'",input$col_locus,"'"), genotype = paste0("'",input$col_genotype,"'")) %>%
+      extract(col = genotype, into = c("A1","A2"), regex = "(.{1})(.{1})", remove = TRUE) %>%
+      arrange(locus)
+    ## "-" fix
+    profile <- profile %>% filter(!is.na(A1), !is.na(A2))
+    ## Validate input columns
+    OK_locus <- all(grepl("^rs[0-9].*", profile$locus))
+    DNA_bases <- c("A", "C", "G", "T", "N", "-")
+    OK_genotype <- all(c(profile$A1 %in% DNA_bases), c(profile$A2 %in% DNA_bases))
+    if(!OK_locus | !OK_genotype) profile <- NULL
+    ## 
     profile
   })
   
@@ -158,15 +253,39 @@ server_fct <- function(input, output, session){
     bar_ranges$y <- NULL
     profile <- Profile()
     if(is.null(profile)) return(NULL)
+    # print("OK - pre profile")
+    # browser()
     profile <- profile %>% as_tibble() %>% profile_AA_x0(df = db$db)
     tilt_ <- if(is.null(input$tilt)) FALSE else (input$tilt == "adjust")
-    result_pop <- genogeo(profile = profile, df = db$db, CI = input$CI, min_n = input$min_n, tilt = tilt_)
+    # print("OK - pre genogeo")
+    result_pop <- genogeo(profile = profile, df = db$db, CI = input$CI/100, min_n = input$min_n, tilt = tilt_)
     ### Fixed clusters based on STRUCTURE analysis
-    result_meta <- genogeo(profile = profile, df = db$db, CI = input$CI, min_n = input$min_n, grouping = "meta", tilt = tilt_)
+    result_meta <- genogeo(profile = profile, df = db$db, CI = input$CI/100, min_n = input$min_n, grouping = "meta", tilt = tilt_)
+    result_list <- list(pop = result_pop, meta = result_meta)
+    ## ADMIXTURE
+    admix_ <- if(is.null(input$admix)) FALSE else (input$admix == "admix")
+    if(!admix_) result_admix <- NULL
+    else{
+      result_admix <- profile_admixture(x0 = profile, df = db$db, grouping = input$meta, hyp = NULL)
+      result_list[[input$meta]] <- add_results(result_list[[input$meta]], result_admix)
+    }
     ##
-    list(pop = result_pop, meta = result_meta)
+    result_list
   })
   
+  # admixture <- eventReactive(list(input$profile_file,input$analyse, input$admix),{
+  #   admix_ <- if(is.null(input$admix)) FALSE else (input$admix == "admix")
+  #   if(!admix_) return(NULL)
+  #   profile <- Profile()
+  #   if(is.null(profile)) return(NULL)
+  #   # print("OK - pre profile")
+  #   # browser()
+  #   profile <- profile %>% as_tibble() %>% profile_AA_x0(df = db$db)
+  #   result_admix <- profile_admixture(x0 = profile, df = db$db, grouping = input$meta, hyp = NULL)
+  #   result_admix
+  # })
+  
+  
   output$side_pvalue <- renderUI({
     res <- result()
     if(is.null(res)) return(NULL)
@@ -220,14 +339,14 @@ server_fct <- function(input, output, session){
   output$barplot_panel <- renderUI({
     div(style = paste0("position:relative; ",
                        "height: ",0.8*session$clientData$output_barplot_width,"px;"),
-        plotOutput("barplot", 
+        withSpinner(plotOutput("barplot", 
                    dblclick = "barplot_dblclick",
                    brush = brushOpts(id = "barplot_brush", 
                                      delay = 800, 
                                      resetOnNew = TRUE, 
                                      direction = "xy"), 
                    hover = hoverOpts(id = "barplot_hover", delay = 100, delayType = "debounce"),
-                   width = "100%"), 
+                   width = "100%"), type = 4), 
         uiOutput("hover_barplot"))
   })
   
@@ -242,8 +361,9 @@ server_fct <- function(input, output, session){
   
   output$result_table <- renderDT({
     res <- result()[[input$meta]]
-    if(is.null(barplot_selected$which)) return(result_table(res))
-    result_table(res %>% inner_join(barplot_selected$which, by = names(res)[1]), .filter = "selected_")
+    ## admix_res <- admixture()
+    if(is.null(barplot_selected$which)) return(result_table(res, lr_listed = input[[paste0("lr_",input$meta)]]))
+    result_table(res %>% inner_join(barplot_selected$which, by = names(res)[1]), .filter = "selected_", lr_listed = input[[paste0("lr_",input$meta)]])
   })
   
   ## LR calculations and controls
@@ -251,8 +371,8 @@ server_fct <- function(input, output, session){
   output$LR_select <- renderUI({
     res <- result()
     if(is.null(res)) return(NULL)
-    meta_pvalue <- res$meta %>% filter(accept) %>% top_n(n = 1, wt = p_value) %>% pull(meta)
-    pop_pvalue <- res$pop %>% filter(accept) %>% top_n(n = 1, wt = p_value) %>% pull(pop)
+    meta_pvalue <- res$meta %>% filter(accept) %>% pull(meta)
+    pop_pvalue <- res$pop %>% filter(accept) %>% pull(pop)
     verticalLayout(
       checkboxGroupInput(inputId = "LR_accept", 
                          label = "LRs with two rejected populations:", 
@@ -261,7 +381,7 @@ server_fct <- function(input, output, session){
                        selectizeInput(inputId = "lr_meta", 
                                       label = "Metapopulations for LR", 
                                       choices = paste(res$meta$meta), 
-                                      selected = unique(c(meta_pvalue,input$lr_meta)),
+                                      selected = meta_pvalue, ## unique(c(meta_pvalue,input$lr_meta)),
                                       multiple = TRUE,
                                       options = list(plugins = list("remove_button", "drag_drop")), 
                                       width = "100%")
@@ -270,7 +390,7 @@ server_fct <- function(input, output, session){
                        selectizeInput(inputId = "lr_pop", 
                                       label = "Populations for LR", 
                                       choices = paste(res$pop$pop),
-                                      selected = unique(c(pop_pvalue, input$lr_pop)),
+                                      selected = pop_pvalue, ## unique(c(pop_pvalue, input$lr_pop)),
                                       multiple = TRUE,
                                       options = list(plugins = list("remove_button", "drag_drop")), 
                                       width = "100%")
@@ -278,17 +398,25 @@ server_fct <- function(input, output, session){
     )
   })
   
-  output$lr_list <- renderDT({
+  LR_Table <- reactive({
     accepted_ <- if(is.null(input$LR_accept)) FALSE else (input$LR_accept == "allow")
-    LR_list(result = result()[[input$meta]], lr_pops = input[[paste0("lr_",input$meta)]], CI = input$CI, accepted = accepted_)
+    res <- result()[[input$meta]]
+    list(
+      res = res, 
+      LR_Tab = LR_table(result_df = res, lr_populations = input[[paste0("lr_",input$meta)]], CI = input$CI/100, only_accepted = !accepted_)
+      )
+  })
+  
+  output$lr_list <- renderDT({
+    LR_Tab <- LR_Table()
+    LR_list(result = LR_Tab$res, LR_tab = LR_Tab$LR_Tab)
   })
   
   observeEvent(input$lr_pop,{ ## Can't delete most probable (based on z_score)
     res <- result()
     if(is.null(res)) return(NULL)
     max_score_pop <- res$pop %>% filter(accept) %>% top_n(n = 1, wt = p_value) %>% pull(var = 1) ## Highest p-value
-    lr_pop <- input$lr_pop
-    lr_pop <- unique(c(max_score_pop, lr_pop))
+    lr_pop <- unique(c(input$lr_pop, max_score_pop))
     updateSelectizeInput(session, "lr_pop", selected = lr_pop)
   })
   
@@ -296,30 +424,43 @@ server_fct <- function(input, output, session){
     res <- result()
     if(is.null(res)) return(NULL)
     max_score_meta <- res$meta %>% filter(accept) %>% top_n(n = 1, wt = p_value) %>% pull(var = 1) ## Highest p-value
-    lr_meta <- input$lr_meta
-    lr_meta <- unique(c(max_score_meta, lr_meta))
+    lr_meta <- unique(c(input$lr_meta, max_score_meta))
     updateSelectizeInput(session, "lr_meta", selected = lr_meta)
   })
   
-  observeEvent(input$result_table_rows_selected,{ ## Can't delete most probable (based on z_score)
-    res <- result()
-    if(is.null(res)) return(NULL)
-    if(input$meta == "meta"){
-      lr_meta <- input$lr_meta
-      lr_meta <- unique(c(res[[input$meta]][input$result_table_rows_selected,1], lr_meta))
-      updateSelectizeInput(session, "lr_meta", selected = lr_meta)
-    }
-    else if(input$meta == "pop"){
-      lr_pop <- input$lr_pop
-      lr_pop <- unique(c(res[[input$meta]][input$result_table_rows_selected,1], lr_pop))
-      updateSelectizeInput(session, "lr_pop", selected = lr_pop)
-    }
-    else return(NULL)
-  })
+  # observeEvent(input$lr_list_rows_current,{
+  #   cat(paste0("Current LR rows: ",paste0(input$lr_list_rows_current, collapse = " "),"\n"))
+  # })
+  
+  # observeEvent(input$result_table_rows_selected,{ ## Can't delete most probable (based on z_score)
+  #   cat(paste0("Selected table rows: ",paste0(input$result_table_rows_selected, collapse = " "),"\n"))    # res <- result()
+  # })
   
   ##
   
   ## PLOTS
+
+  LR_plot <- function(...) NULL
+  
+  plot_LR <- reactive({
+    LR_Tab <- LR_Table()
+    if(is.null(LR_Tab$LR_Tab) | nrow(LR_Tab$LR_Tab) == 0) return(NULL)
+    LR_plot(result = LR_Tab$res, LR_list = LR_Tab$LR_Tab, rows = input$lr_list_rows_current, theme_ = theme_bw(base_size = 18))
+  })
+  
+  output$LRplot <- renderPlot({
+    plot_LR()
+  },height = function() {
+    scale <- length(input$lr_list_rows_current)
+    # 0.8*max(10, scale)/10*session$clientData$output_LRplot_width
+    scale*45 + 200
+  })
+  
+  output$LRplot_panel <- renderUI({
+    div(style = paste0("position:relative; ",
+                       "height: ",0.8*session$clientData$output_LRplot_width,"px;"),
+        withSpinner(plotOutput("LRplot", width = "100%"), type = 4))
+  })
   
   plot_bars <- reactive({
     res <- result()
@@ -334,14 +475,33 @@ server_fct <- function(input, output, session){
       bar_ranges$y <- c(brush$ymin, brush$ymax)
       barplot_selected$which <- NULL
     } else {
-      bar_ranges$x <- NULL
-      bar_ranges$y <- NULL
-      barplot_selected$which <- NULL
+      if(is.null(bar_ranges$x)){
+        showModal(
+          modalDialog(title = "Error bar plot", size = "l", 
+                      easyClose = TRUE, footer = modalButton("Close"),
+                      fluidPage(div(style = paste0("position:relative; ",
+                                 "height: ",2*0.8*session$clientData$output_barplot_width,"px;"),
+                      plotOutput("barplotPopup", width = paste0(1.8*session$clientData$output_barplot_width,"px"))
+                      ))
+          )
+        )
+      }
+      else{
+        bar_ranges$x <- NULL
+        bar_ranges$y <- NULL
+        barplot_selected$which <- NULL
+      }
     }
   })
   
+  output$barplotPopup <- renderPlot({ 
+    plot_bars() + theme_bw(base_size = 18)
+  },height = function() {
+    0.8*session$clientData$output_barplotPopup_width
+  })
+  
   output$barplot <- renderPlot({ 
-    plot_bars() + theme_bw(base_size = 16)
+    plot_bars() + theme_bw(base_size = 18)
   },height = function() {
     0.8*session$clientData$output_barplot_width
   })
@@ -367,15 +527,34 @@ server_fct <- function(input, output, session){
       map_ranges$x <- c(brush$xmin, brush$xmax)
       map_ranges$y <- c(brush$ymin, brush$ymax)
     } else {
-      map_ranges$x <- NULL
-      map_ranges$y <- NULL
+      if(is.null(map_ranges$x)){
+        showModal(
+          modalDialog(title = "Map plot",size = "l", 
+                      easyClose = TRUE, footer = modalButton("Close"),
+                      fluidPage(div(style = paste0("position:relative; ",
+                                                   "height: ",2*0.8*session$clientData$output_map_width,"px;"),
+                      plotOutput("map_popup", paste0(1.8*session$clientData$output_barplot_width,"px"))
+                      ))
+          )
+        )
+      }
+      else{
+        map_ranges$x <- NULL
+        map_ranges$y <- NULL
+      }
     }
   })
   
+  output$map_popup <- renderPlot({
+    plot_map() + theme_bw(base_size = 18)
+  },height = function() {
+    0.8*session$clientData$output_map_popup_width
+  })
+  
   output$map <- renderPlot({
-    plot_map() + 
+    plot_map() +  ## $plot
       coord_cartesian(xlim=map_ranges$x, ylim=map_ranges$y, expand = FALSE) + 
-      theme_bw(base_size = 16)
+      theme_bw(base_size = 18)
   },height = function() {
     0.8*session$clientData$output_map_width
   })
@@ -385,10 +564,11 @@ server_fct <- function(input, output, session){
   output$hover_map <- renderUI({
     res <- result()
     if(is.null(res)) return(NULL)
+    ## bg_colours <- bar_colour(res[,c("logP","accept",names(res)[1])], alpha = 0.1)
     hover <- input$map_hover
     if(is.null(hover)) return(NULL)
     point <- nearPoints(res[[input$meta]], hover, threshold = 5, maxpoints = 1)
-    tool_tip(hover = hover, point = point)
+    tool_tip(hover = hover, point = point) ## , bg = bg_colours[paste(point[[1]][1])]
   })
   
   output$hover_barplot <- renderUI({
@@ -420,6 +600,7 @@ server_fct <- function(input, output, session){
   # 
 
   output$report_download = downloadHandler(
+##  filename = "test.html",
     filename = function(){
       paste(sub("\\.[[:alnum:]]*.$","",input$profile_file$name), sep =".",
             switch(
@@ -427,16 +608,17 @@ server_fct <- function(input, output, session){
             ))
     },
     content = function(file) {
-      withProgress(message = "Generating report..", {
-      ## out <- make_report()
+      ## withProgress(message = "Generating report..", {
       src <- list(rmd_file = normalizePath(system.file("deployable_app", "aims_report.Rmd", package = "genogeographer")))
-      ## logo=normalizePath('kulogo_small.png'))
+      ## cat(file = stderr(), src$rmd_file, "\n")
       # temporarily switch to the temp dir, in case you do not have write
       # permission to the current working directory
       owd <- setwd(tempdir())
+      cat(file = stderr(), owd, "\n")
       on.exit(setwd(owd))
-      file.copy(src$rmd_file, 'aims_report_.Rmd', overwrite = TRUE)
-      out <- rmarkdown::render(input = 'aims_report_.Rmd', output_format = switch(
+      file.copy(src$rmd_file, 'aims_report.Rmd', overwrite = TRUE)
+      out <- rmarkdown::render(input = 'aims_report.Rmd', clean = TRUE,
+                               output_format = switch(
         input$format,
         PDF = pdf_document(), HTML = html_document(), Word = word_document()
         ),
@@ -446,7 +628,9 @@ server_fct <- function(input, output, session){
           set_output = input$format
           )
         )
-      })
+      ## cat(file = stderr(), "File start", "\n")
+      ## out <- render('aims_report.Rmd', clean = TRUE)
+      ## cat(file = stderr(), "File end", "\n")
       file.rename(out, file)
     }
     )
